# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReinstatementCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'reinstatement_status': 'ReinstatementStatus',
        'reinstatement_date': 'datetime',
        'depth': 'float',
        'length': 'float',
        'width': 'float',
        'reinstatement_coordinates': 'object',
        'secondary_reinstatement_coordinates': 'object',
        'location_description': 'str',
        'location_types': 'list[LocationType]',
        'reinstatement_evidence': 'bool',
        'file_ids': 'list[float]',
        'final_reinstatement': 'bool',
        'number_of_holes': 'float',
        'permit_reference_number': 'str',
        'response_to_remedial_works': 'bool',
        'base_courses_affected': 'bool'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'reinstatement_status': 'reinstatement_status',
        'reinstatement_date': 'reinstatement_date',
        'depth': 'depth',
        'length': 'length',
        'width': 'width',
        'reinstatement_coordinates': 'reinstatement_coordinates',
        'secondary_reinstatement_coordinates': 'secondary_reinstatement_coordinates',
        'location_description': 'location_description',
        'location_types': 'location_types',
        'reinstatement_evidence': 'reinstatement_evidence',
        'file_ids': 'file_ids',
        'final_reinstatement': 'final_reinstatement',
        'number_of_holes': 'number_of_holes',
        'permit_reference_number': 'permit_reference_number',
        'response_to_remedial_works': 'response_to_remedial_works',
        'base_courses_affected': 'base_courses_affected'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, reinstatement_status=None, reinstatement_date=None, depth=None, length=None, width=None, reinstatement_coordinates=None, secondary_reinstatement_coordinates=None, location_description=None, location_types=None, reinstatement_evidence=None, file_ids=None, final_reinstatement=None, number_of_holes=None, permit_reference_number=None, response_to_remedial_works=None, base_courses_affected=None):  # noqa: E501
        """ReinstatementCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._reinstatement_status = None
        self._reinstatement_date = None
        self._depth = None
        self._length = None
        self._width = None
        self._reinstatement_coordinates = None
        self._secondary_reinstatement_coordinates = None
        self._location_description = None
        self._location_types = None
        self._reinstatement_evidence = None
        self._file_ids = None
        self._final_reinstatement = None
        self._number_of_holes = None
        self._permit_reference_number = None
        self._response_to_remedial_works = None
        self._base_courses_affected = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.reinstatement_status = reinstatement_status
        self.reinstatement_date = reinstatement_date
        if depth is not None:
            self.depth = depth
        if length is not None:
            self.length = length
        if width is not None:
            self.width = width
        self.reinstatement_coordinates = reinstatement_coordinates
        if secondary_reinstatement_coordinates is not None:
            self.secondary_reinstatement_coordinates = secondary_reinstatement_coordinates
        self.location_description = location_description
        self.location_types = location_types
        self.reinstatement_evidence = reinstatement_evidence
        if file_ids is not None:
            self.file_ids = file_ids
        if final_reinstatement is not None:
            self.final_reinstatement = final_reinstatement
        if number_of_holes is not None:
            self.number_of_holes = number_of_holes
        if permit_reference_number is not None:
            self.permit_reference_number = permit_reference_number
        if response_to_remedial_works is not None:
            self.response_to_remedial_works = response_to_remedial_works
        if base_courses_affected is not None:
            self.base_courses_affected = base_courses_affected

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this ReinstatementCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this ReinstatementCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this ReinstatementCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this ReinstatementCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this ReinstatementCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this ReinstatementCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def reinstatement_status(self):
        """Gets the reinstatement_status of this ReinstatementCreateRequest.  # noqa: E501


        :return: The reinstatement_status of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: ReinstatementStatus
        """
        return self._reinstatement_status

    @reinstatement_status.setter
    def reinstatement_status(self, reinstatement_status):
        """Sets the reinstatement_status of this ReinstatementCreateRequest.


        :param reinstatement_status: The reinstatement_status of this ReinstatementCreateRequest.  # noqa: E501
        :type: ReinstatementStatus
        """
        if reinstatement_status is None:
            raise ValueError("Invalid value for `reinstatement_status`, must not be `None`")  # noqa: E501

        self._reinstatement_status = reinstatement_status

    @property
    def reinstatement_date(self):
        """Gets the reinstatement_date of this ReinstatementCreateRequest.  # noqa: E501

        reinstatement_date must be in the past Must be after actual start date Must be before actual end date (if entered)  # noqa: E501

        :return: The reinstatement_date of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._reinstatement_date

    @reinstatement_date.setter
    def reinstatement_date(self, reinstatement_date):
        """Sets the reinstatement_date of this ReinstatementCreateRequest.

        reinstatement_date must be in the past Must be after actual start date Must be before actual end date (if entered)  # noqa: E501

        :param reinstatement_date: The reinstatement_date of this ReinstatementCreateRequest.  # noqa: E501
        :type: datetime
        """
        if reinstatement_date is None:
            raise ValueError("Invalid value for `reinstatement_date`, must not be `None`")  # noqa: E501

        self._reinstatement_date = reinstatement_date

    @property
    def depth(self):
        """Gets the depth of this ReinstatementCreateRequest.  # noqa: E501

        Is number between 0 and 99.99 inclusive, to two decimal places. Required if reinstatement type is excavation.  # noqa: E501

        :return: The depth of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this ReinstatementCreateRequest.

        Is number between 0 and 99.99 inclusive, to two decimal places. Required if reinstatement type is excavation.  # noqa: E501

        :param depth: The depth of this ReinstatementCreateRequest.  # noqa: E501
        :type: float
        """

        self._depth = depth

    @property
    def length(self):
        """Gets the length of this ReinstatementCreateRequest.  # noqa: E501

        Is number between 0 and 9999.99 inclusive, to two decimal places Required if reinstatement type is excavation.  # noqa: E501

        :return: The length of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this ReinstatementCreateRequest.

        Is number between 0 and 9999.99 inclusive, to two decimal places Required if reinstatement type is excavation.  # noqa: E501

        :param length: The length of this ReinstatementCreateRequest.  # noqa: E501
        :type: float
        """

        self._length = length

    @property
    def width(self):
        """Gets the width of this ReinstatementCreateRequest.  # noqa: E501

        Is number between 0 and 99.99 inclusive, to two decimal places Required if reinstatement type is excavation.  # noqa: E501

        :return: The width of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this ReinstatementCreateRequest.

        Is number between 0 and 99.99 inclusive, to two decimal places Required if reinstatement type is excavation.  # noqa: E501

        :param width: The width of this ReinstatementCreateRequest.  # noqa: E501
        :type: float
        """

        self._width = width

    @property
    def reinstatement_coordinates(self):
        """Gets the reinstatement_coordinates of this ReinstatementCreateRequest.  # noqa: E501

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :return: The reinstatement_coordinates of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: object
        """
        return self._reinstatement_coordinates

    @reinstatement_coordinates.setter
    def reinstatement_coordinates(self, reinstatement_coordinates):
        """Sets the reinstatement_coordinates of this ReinstatementCreateRequest.

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :param reinstatement_coordinates: The reinstatement_coordinates of this ReinstatementCreateRequest.  # noqa: E501
        :type: object
        """
        if reinstatement_coordinates is None:
            raise ValueError("Invalid value for `reinstatement_coordinates`, must not be `None`")  # noqa: E501

        self._reinstatement_coordinates = reinstatement_coordinates

    @property
    def secondary_reinstatement_coordinates(self):
        """Gets the secondary_reinstatement_coordinates of this ReinstatementCreateRequest.  # noqa: E501

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon, if provided  # noqa: E501

        :return: The secondary_reinstatement_coordinates of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: object
        """
        return self._secondary_reinstatement_coordinates

    @secondary_reinstatement_coordinates.setter
    def secondary_reinstatement_coordinates(self, secondary_reinstatement_coordinates):
        """Sets the secondary_reinstatement_coordinates of this ReinstatementCreateRequest.

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon, if provided  # noqa: E501

        :param secondary_reinstatement_coordinates: The secondary_reinstatement_coordinates of this ReinstatementCreateRequest.  # noqa: E501
        :type: object
        """

        self._secondary_reinstatement_coordinates = secondary_reinstatement_coordinates

    @property
    def location_description(self):
        """Gets the location_description of this ReinstatementCreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The location_description of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this ReinstatementCreateRequest.

        Max length 500 characters  # noqa: E501

        :param location_description: The location_description of this ReinstatementCreateRequest.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    @property
    def location_types(self):
        """Gets the location_types of this ReinstatementCreateRequest.  # noqa: E501

        Array values must be unique Must not contain null or undefined values  # noqa: E501

        :return: The location_types of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: list[LocationType]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this ReinstatementCreateRequest.

        Array values must be unique Must not contain null or undefined values  # noqa: E501

        :param location_types: The location_types of this ReinstatementCreateRequest.  # noqa: E501
        :type: list[LocationType]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def reinstatement_evidence(self):
        """Gets the reinstatement_evidence of this ReinstatementCreateRequest.  # noqa: E501

        Whether reinstatement evidence has been supplied  # noqa: E501

        :return: The reinstatement_evidence of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._reinstatement_evidence

    @reinstatement_evidence.setter
    def reinstatement_evidence(self, reinstatement_evidence):
        """Sets the reinstatement_evidence of this ReinstatementCreateRequest.

        Whether reinstatement evidence has been supplied  # noqa: E501

        :param reinstatement_evidence: The reinstatement_evidence of this ReinstatementCreateRequest.  # noqa: E501
        :type: bool
        """
        if reinstatement_evidence is None:
            raise ValueError("Invalid value for `reinstatement_evidence`, must not be `None`")  # noqa: E501

        self._reinstatement_evidence = reinstatement_evidence

    @property
    def file_ids(self):
        """Gets the file_ids of this ReinstatementCreateRequest.  # noqa: E501

        Required if reinstatement_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :return: The file_ids of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._file_ids

    @file_ids.setter
    def file_ids(self, file_ids):
        """Sets the file_ids of this ReinstatementCreateRequest.

        Required if reinstatement_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :param file_ids: The file_ids of this ReinstatementCreateRequest.  # noqa: E501
        :type: list[float]
        """

        self._file_ids = file_ids

    @property
    def final_reinstatement(self):
        """Gets the final_reinstatement of this ReinstatementCreateRequest.  # noqa: E501

        Whether it is a final reinstatement Required if reinstatement type is excavation  # noqa: E501

        :return: The final_reinstatement of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._final_reinstatement

    @final_reinstatement.setter
    def final_reinstatement(self, final_reinstatement):
        """Sets the final_reinstatement of this ReinstatementCreateRequest.

        Whether it is a final reinstatement Required if reinstatement type is excavation  # noqa: E501

        :param final_reinstatement: The final_reinstatement of this ReinstatementCreateRequest.  # noqa: E501
        :type: bool
        """

        self._final_reinstatement = final_reinstatement

    @property
    def number_of_holes(self):
        """Gets the number_of_holes of this ReinstatementCreateRequest.  # noqa: E501

        Must be a number between 0 and 100 Required if reinstatement type is not excavation  # noqa: E501

        :return: The number_of_holes of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._number_of_holes

    @number_of_holes.setter
    def number_of_holes(self, number_of_holes):
        """Sets the number_of_holes of this ReinstatementCreateRequest.

        Must be a number between 0 and 100 Required if reinstatement type is not excavation  # noqa: E501

        :param number_of_holes: The number_of_holes of this ReinstatementCreateRequest.  # noqa: E501
        :type: float
        """

        self._number_of_holes = number_of_holes

    @property
    def permit_reference_number(self):
        """Gets the permit_reference_number of this ReinstatementCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The permit_reference_number of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._permit_reference_number

    @permit_reference_number.setter
    def permit_reference_number(self, permit_reference_number):
        """Sets the permit_reference_number of this ReinstatementCreateRequest.

        Max length 100 characters  # noqa: E501

        :param permit_reference_number: The permit_reference_number of this ReinstatementCreateRequest.  # noqa: E501
        :type: str
        """

        self._permit_reference_number = permit_reference_number

    @property
    def response_to_remedial_works(self):
        """Gets the response_to_remedial_works of this ReinstatementCreateRequest.  # noqa: E501

        Must be provided if base_courses_affected is provided  # noqa: E501

        :return: The response_to_remedial_works of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._response_to_remedial_works

    @response_to_remedial_works.setter
    def response_to_remedial_works(self, response_to_remedial_works):
        """Sets the response_to_remedial_works of this ReinstatementCreateRequest.

        Must be provided if base_courses_affected is provided  # noqa: E501

        :param response_to_remedial_works: The response_to_remedial_works of this ReinstatementCreateRequest.  # noqa: E501
        :type: bool
        """

        self._response_to_remedial_works = response_to_remedial_works

    @property
    def base_courses_affected(self):
        """Gets the base_courses_affected of this ReinstatementCreateRequest.  # noqa: E501

        Must be provided if response_to_remedial_works is provided  # noqa: E501

        :return: The base_courses_affected of this ReinstatementCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._base_courses_affected

    @base_courses_affected.setter
    def base_courses_affected(self, base_courses_affected):
        """Sets the base_courses_affected of this ReinstatementCreateRequest.

        Must be provided if response_to_remedial_works is provided  # noqa: E501

        :param base_courses_affected: The base_courses_affected of this ReinstatementCreateRequest.  # noqa: E501
        :type: bool
        """

        self._base_courses_affected = base_courses_affected

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReinstatementCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReinstatementCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PrivateStreetSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'private_street_reference_number': 'str',
        'proposed_start_date': 'datetime',
        'proposed_start_time': 'datetime',
        'proposed_end_date': 'datetime',
        'proposed_end_time': 'datetime',
        'private_street_status': 'PrivateStreetStatusResponse',
        'private_street_status_string': 'str'
    }

    attribute_map = {
        'private_street_reference_number': 'private_street_reference_number',
        'proposed_start_date': 'proposed_start_date',
        'proposed_start_time': 'proposed_start_time',
        'proposed_end_date': 'proposed_end_date',
        'proposed_end_time': 'proposed_end_time',
        'private_street_status': 'private_street_status',
        'private_street_status_string': 'private_street_status_string'
    }

    def __init__(self, private_street_reference_number=None, proposed_start_date=None, proposed_start_time=None, proposed_end_date=None, proposed_end_time=None, private_street_status=None, private_street_status_string=None):  # noqa: E501
        """PrivateStreetSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._private_street_reference_number = None
        self._proposed_start_date = None
        self._proposed_start_time = None
        self._proposed_end_date = None
        self._proposed_end_time = None
        self._private_street_status = None
        self._private_street_status_string = None
        self.discriminator = None
        self.private_street_reference_number = private_street_reference_number
        self.proposed_start_date = proposed_start_date
        if proposed_start_time is not None:
            self.proposed_start_time = proposed_start_time
        self.proposed_end_date = proposed_end_date
        if proposed_end_time is not None:
            self.proposed_end_time = proposed_end_time
        self.private_street_status = private_street_status
        self.private_street_status_string = private_street_status_string

    @property
    def private_street_reference_number(self):
        """Gets the private_street_reference_number of this PrivateStreetSummaryResponse.  # noqa: E501


        :return: The private_street_reference_number of this PrivateStreetSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._private_street_reference_number

    @private_street_reference_number.setter
    def private_street_reference_number(self, private_street_reference_number):
        """Sets the private_street_reference_number of this PrivateStreetSummaryResponse.


        :param private_street_reference_number: The private_street_reference_number of this PrivateStreetSummaryResponse.  # noqa: E501
        :type: str
        """
        if private_street_reference_number is None:
            raise ValueError("Invalid value for `private_street_reference_number`, must not be `None`")  # noqa: E501

        self._private_street_reference_number = private_street_reference_number

    @property
    def proposed_start_date(self):
        """Gets the proposed_start_date of this PrivateStreetSummaryResponse.  # noqa: E501


        :return: The proposed_start_date of this PrivateStreetSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._proposed_start_date

    @proposed_start_date.setter
    def proposed_start_date(self, proposed_start_date):
        """Sets the proposed_start_date of this PrivateStreetSummaryResponse.


        :param proposed_start_date: The proposed_start_date of this PrivateStreetSummaryResponse.  # noqa: E501
        :type: datetime
        """
        if proposed_start_date is None:
            raise ValueError("Invalid value for `proposed_start_date`, must not be `None`")  # noqa: E501

        self._proposed_start_date = proposed_start_date

    @property
    def proposed_start_time(self):
        """Gets the proposed_start_time of this PrivateStreetSummaryResponse.  # noqa: E501


        :return: The proposed_start_time of this PrivateStreetSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._proposed_start_time

    @proposed_start_time.setter
    def proposed_start_time(self, proposed_start_time):
        """Sets the proposed_start_time of this PrivateStreetSummaryResponse.


        :param proposed_start_time: The proposed_start_time of this PrivateStreetSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._proposed_start_time = proposed_start_time

    @property
    def proposed_end_date(self):
        """Gets the proposed_end_date of this PrivateStreetSummaryResponse.  # noqa: E501


        :return: The proposed_end_date of this PrivateStreetSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._proposed_end_date

    @proposed_end_date.setter
    def proposed_end_date(self, proposed_end_date):
        """Sets the proposed_end_date of this PrivateStreetSummaryResponse.


        :param proposed_end_date: The proposed_end_date of this PrivateStreetSummaryResponse.  # noqa: E501
        :type: datetime
        """
        if proposed_end_date is None:
            raise ValueError("Invalid value for `proposed_end_date`, must not be `None`")  # noqa: E501

        self._proposed_end_date = proposed_end_date

    @property
    def proposed_end_time(self):
        """Gets the proposed_end_time of this PrivateStreetSummaryResponse.  # noqa: E501


        :return: The proposed_end_time of this PrivateStreetSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._proposed_end_time

    @proposed_end_time.setter
    def proposed_end_time(self, proposed_end_time):
        """Sets the proposed_end_time of this PrivateStreetSummaryResponse.


        :param proposed_end_time: The proposed_end_time of this PrivateStreetSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._proposed_end_time = proposed_end_time

    @property
    def private_street_status(self):
        """Gets the private_street_status of this PrivateStreetSummaryResponse.  # noqa: E501


        :return: The private_street_status of this PrivateStreetSummaryResponse.  # noqa: E501
        :rtype: PrivateStreetStatusResponse
        """
        return self._private_street_status

    @private_street_status.setter
    def private_street_status(self, private_street_status):
        """Sets the private_street_status of this PrivateStreetSummaryResponse.


        :param private_street_status: The private_street_status of this PrivateStreetSummaryResponse.  # noqa: E501
        :type: PrivateStreetStatusResponse
        """
        if private_street_status is None:
            raise ValueError("Invalid value for `private_street_status`, must not be `None`")  # noqa: E501

        self._private_street_status = private_street_status

    @property
    def private_street_status_string(self):
        """Gets the private_street_status_string of this PrivateStreetSummaryResponse.  # noqa: E501


        :return: The private_street_status_string of this PrivateStreetSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._private_street_status_string

    @private_street_status_string.setter
    def private_street_status_string(self, private_street_status_string):
        """Sets the private_street_status_string of this PrivateStreetSummaryResponse.


        :param private_street_status_string: The private_street_status_string of this PrivateStreetSummaryResponse.  # noqa: E501
        :type: str
        """
        if private_street_status_string is None:
            raise ValueError("Invalid value for `private_street_status_string`, must not be `None`")  # noqa: E501

        self._private_street_status_string = private_street_status_string

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PrivateStreetSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrivateStreetSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#!/usr/bin/env python3
"""
Script to fix swagger client imports by converting absolute imports to relative imports.
This script processes Python files within each 'swagger_client' directory
(e.g., src/streetmanager/work/swagger_client, src/streetmanager/geojson/swagger_client, etc.).

For each Python file, it:
1. Calculates the necessary relative import prefix ('.', '..', etc.) based on the
   file's depth relative to its 'swagger_client' root directory.
2. Converts absolute imports like 'from swagger_client.module import Name' to
   'from <prefix>.module import Name'.
3. Converts absolute imports like 'import swagger_client.module' to
   'import <prefix>.module'.
4. Ensures the main __init__.py of each swagger_client package correctly
   exports 'DefaultApi' (and other core components) by importing them from
   its submodules (e.g., 'from .api import DefaultApi').
"""

import re
from pathlib import Path

def convert_imports_in_file(file_path: Path, swagger_client_root: Path, project_root: Path):
    """
    Converts absolute 'swagger_client.' imports to relative imports in a single file.
    Also, handles specific import patterns for __init__.py files.
    """
    try:
        content = file_path.read_text(encoding='utf-8')
    except Exception as e:
        print(f"Error reading file {file_path}: {e}")
        return
    
    original_content = content

    # Determine the relative path from the swagger_client_root to the current file's directory.
    # This determines the number of dots needed for the relative import prefix.
    try:
        relative_dir_of_file = file_path.parent.relative_to(swagger_client_root)
    except ValueError:
        # This can happen if file_path is not under swagger_client_root, which shouldn't occur with current logic.
        print(f"Error: File {file_path} does not seem to be under swagger_client_root {swagger_client_root}")
        return

    # Depth is the number of directory levels from swagger_client_root to the file's directory.
    # e.g., 0 for files directly in swagger_client_root (e.g., swagger_client/api_client.py)
    #       1 for files in swagger_client_root/api/ (e.g., swagger_client/api/default_api.py)
    depth = len(relative_dir_of_file.parts)

    # Calculate the dot_prefix:
    # - If depth is 0 (file is in swagger_client_root), prefix is "."
    # - If depth is 1 (file is in swagger_client_root/api), prefix is ".."
    # - And so on.
    dot_prefix = "." + "." * depth

    # General rule: Convert 'from swagger_client.sub.module' to 'from <dot_prefix>.sub.module'
    content = re.sub(r'from swagger_client\.([\w.]+)', rf'from {dot_prefix}.\1', content)

    # General rule: Convert 'import swagger_client.sub.module' to 'import <dot_prefix>.sub.module'
    content = re.sub(r'import swagger_client\.([\w.]+)', rf'import {dot_prefix}.\1', content)

    # Specific fix for the main __init__.py of a swagger_client package
    # (e.g., src/streetmanager/work/swagger_client/__init__.py)
    if file_path.name == "__init__.py" and file_path.parent == swagger_client_root:
        # This __init__.py should expose APIs, e.g., DefaultApi.
        # It often imports DefaultApi from its 'api' subpackage.
        # We want to ensure 'from .api import DefaultApi' or 'from .api.default_api import DefaultApi'.
        # The `api/__init__.py` should itself export DefaultApi via `from .default_api import DefaultApi`.
        # So, `from .api import DefaultApi` is preferred in this top-level `__init__.py`.

        # Correct a common misconfiguration where it might try to import directly from a sibling default_api.py
        # (e.g., "from .default_api import DefaultApi") instead of from the "api" subpackage.
        # This pattern looks for "# import apis into sdk package" followed by the problematic import.
        content = re.sub(
            r'(# import apis into sdk package\s*\n\s*)from \.default_api import DefaultApi',
            r'\1from .api import DefaultApi',
            content
        )
        # If the generator produced `from .api.default_api import DefaultApi` (after general replacements),
        # that is also acceptable and the above regex won't modify it.

    # Specific fix for swagger_client/api/__init__.py
    # This file should import its own contents using single-dot relative imports.
    # e.g., 'from .default_api import DefaultApi'
    if file_path.name == "__init__.py" and file_path.parent.name == "api" and file_path.parent.parent == swagger_client_root:
        # If the general rule (due to original `from swagger_client.api.default_api`) changed an import to
        # something like 'from ..api.default_api import DefaultApi', it's wrong for this file.
        # It should be 'from .default_api import DefaultApi'.
        content = re.sub(
            r'from \.\.api\.default_api import DefaultApi', # Problematic pattern after general rule
            r'from .default_api import DefaultApi',         # Corrected pattern
            content
        )

    if content != original_content:
        print(f"Updating imports in: {file_path.relative_to(project_root)}")
        try:
            file_path.write_text(content, encoding='utf-8')
        except Exception as e:
            print(f"Error writing file {file_path}: {e}")
    else:
        print(f"No import changes needed for: {file_path.relative_to(project_root)}")

def main():
    # Determine the project root (assuming script is in 'scripts/' subdirectory of project root)
    try:
        project_root = Path(__file__).resolve().parent.parent
    except NameError: # Fallback if __file__ is not defined (e.g. interactive)
        project_root = Path(".").resolve()

    print(f"Project root identified as: {project_root}")
    base_src_dir = project_root / 'src' / 'streetmanager'

    submodule_types = ["work", "geojson", "lookup"]

    for submodule_name in submodule_types:
        swagger_client_root = base_src_dir / submodule_name / "swagger_client"
        if swagger_client_root.is_dir():
            print(f"\nProcessing swagger client module: {swagger_client_root.relative_to(project_root)}")
            
            python_files = list(swagger_client_root.rglob('*.py'))
            if not python_files:
                print(f"No Python files found in {swagger_client_root.relative_to(project_root)}")
                continue
            
            # Sort files for consistent processing order (optional, but good for logs)
            python_files.sort()

            for file_path in python_files:
                # print(f"--- Analyzing: {file_path.relative_to(project_root)}") # Verbose
                convert_imports_in_file(file_path, swagger_client_root, project_root)
        else:
            print(f"Directory not found, skipping: {swagger_client_root.relative_to(project_root)}")

    print("\nImport fixing process completed.")

if __name__ == '__main__':
    main() 


# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InspectionCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'inspection_type': 'InspectionType',
        'inspection_start_date': 'datetime',
        'inspection_category': 'AllOfInspectionCreateRequestInspectionCategory',
        'inspection_outcome': 'InspectionOutcome',
        'failure_reason_details': 'list[FailureReasonDetails]',
        'inspection_outcome_details': 'str',
        'was_call_logged': 'bool',
        'call_logged_to': 'str',
        'call_logged_reference': 'str',
        'call_logged_summary': 'str',
        'defect_fixed_on_site': 'AllOfInspectionCreateRequestDefectFixedOnSite',
        'additional_comments': 'str',
        'inspection_evidence': 'bool',
        'file_ids': 'list[float]',
        'reinspection_date': 'datetime',
        'reinspection_date_time': 'datetime',
        'reinspection_type': 'AllOfInspectionCreateRequestReinspectionType',
        'reinspection_category': 'AllOfInspectionCreateRequestReinspectionCategory',
        'username': 'str',
        'inspector_name': 'str',
        'made_safe_by_ha': 'bool',
        'non_compliance_reference_number': 'str'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'inspection_type': 'inspection_type',
        'inspection_start_date': 'inspection_start_date',
        'inspection_category': 'inspection_category',
        'inspection_outcome': 'inspection_outcome',
        'failure_reason_details': 'failure_reason_details',
        'inspection_outcome_details': 'inspection_outcome_details',
        'was_call_logged': 'was_call_logged',
        'call_logged_to': 'call_logged_to',
        'call_logged_reference': 'call_logged_reference',
        'call_logged_summary': 'call_logged_summary',
        'defect_fixed_on_site': 'defect_fixed_on_site',
        'additional_comments': 'additional_comments',
        'inspection_evidence': 'inspection_evidence',
        'file_ids': 'file_ids',
        'reinspection_date': 'reinspection_date',
        'reinspection_date_time': 'reinspection_date_time',
        'reinspection_type': 'reinspection_type',
        'reinspection_category': 'reinspection_category',
        'username': 'username',
        'inspector_name': 'inspector_name',
        'made_safe_by_ha': 'made_safe_by_ha',
        'non_compliance_reference_number': 'non_compliance_reference_number'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, inspection_type=None, inspection_start_date=None, inspection_category=None, inspection_outcome=None, failure_reason_details=None, inspection_outcome_details=None, was_call_logged=None, call_logged_to=None, call_logged_reference=None, call_logged_summary=None, defect_fixed_on_site=None, additional_comments=None, inspection_evidence=None, file_ids=None, reinspection_date=None, reinspection_date_time=None, reinspection_type=None, reinspection_category=None, username=None, inspector_name=None, made_safe_by_ha=None, non_compliance_reference_number=None):  # noqa: E501
        """InspectionCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._inspection_type = None
        self._inspection_start_date = None
        self._inspection_category = None
        self._inspection_outcome = None
        self._failure_reason_details = None
        self._inspection_outcome_details = None
        self._was_call_logged = None
        self._call_logged_to = None
        self._call_logged_reference = None
        self._call_logged_summary = None
        self._defect_fixed_on_site = None
        self._additional_comments = None
        self._inspection_evidence = None
        self._file_ids = None
        self._reinspection_date = None
        self._reinspection_date_time = None
        self._reinspection_type = None
        self._reinspection_category = None
        self._username = None
        self._inspector_name = None
        self._made_safe_by_ha = None
        self._non_compliance_reference_number = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.inspection_type = inspection_type
        self.inspection_start_date = inspection_start_date
        if inspection_category is not None:
            self.inspection_category = inspection_category
        self.inspection_outcome = inspection_outcome
        if failure_reason_details is not None:
            self.failure_reason_details = failure_reason_details
        if inspection_outcome_details is not None:
            self.inspection_outcome_details = inspection_outcome_details
        if was_call_logged is not None:
            self.was_call_logged = was_call_logged
        if call_logged_to is not None:
            self.call_logged_to = call_logged_to
        if call_logged_reference is not None:
            self.call_logged_reference = call_logged_reference
        if call_logged_summary is not None:
            self.call_logged_summary = call_logged_summary
        if defect_fixed_on_site is not None:
            self.defect_fixed_on_site = defect_fixed_on_site
        if additional_comments is not None:
            self.additional_comments = additional_comments
        self.inspection_evidence = inspection_evidence
        if file_ids is not None:
            self.file_ids = file_ids
        if reinspection_date is not None:
            self.reinspection_date = reinspection_date
        if reinspection_date_time is not None:
            self.reinspection_date_time = reinspection_date_time
        if reinspection_type is not None:
            self.reinspection_type = reinspection_type
        if reinspection_category is not None:
            self.reinspection_category = reinspection_category
        self.username = username
        if inspector_name is not None:
            self.inspector_name = inspector_name
        if made_safe_by_ha is not None:
            self.made_safe_by_ha = made_safe_by_ha
        if non_compliance_reference_number is not None:
            self.non_compliance_reference_number = non_compliance_reference_number

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this InspectionCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this InspectionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this InspectionCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this InspectionCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this InspectionCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this InspectionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this InspectionCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this InspectionCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def inspection_type(self):
        """Gets the inspection_type of this InspectionCreateRequest.  # noqa: E501


        :return: The inspection_type of this InspectionCreateRequest.  # noqa: E501
        :rtype: InspectionType
        """
        return self._inspection_type

    @inspection_type.setter
    def inspection_type(self, inspection_type):
        """Sets the inspection_type of this InspectionCreateRequest.


        :param inspection_type: The inspection_type of this InspectionCreateRequest.  # noqa: E501
        :type: InspectionType
        """
        if inspection_type is None:
            raise ValueError("Invalid value for `inspection_type`, must not be `None`")  # noqa: E501

        self._inspection_type = inspection_type

    @property
    def inspection_start_date(self):
        """Gets the inspection_start_date of this InspectionCreateRequest.  # noqa: E501

        inspection_start_date must be in the past  # noqa: E501

        :return: The inspection_start_date of this InspectionCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._inspection_start_date

    @inspection_start_date.setter
    def inspection_start_date(self, inspection_start_date):
        """Sets the inspection_start_date of this InspectionCreateRequest.

        inspection_start_date must be in the past  # noqa: E501

        :param inspection_start_date: The inspection_start_date of this InspectionCreateRequest.  # noqa: E501
        :type: datetime
        """
        if inspection_start_date is None:
            raise ValueError("Invalid value for `inspection_start_date`, must not be `None`")  # noqa: E501

        self._inspection_start_date = inspection_start_date

    @property
    def inspection_category(self):
        """Gets the inspection_category of this InspectionCreateRequest.  # noqa: E501

        See business rules section 10.2 - Inspection types and categories  # noqa: E501

        :return: The inspection_category of this InspectionCreateRequest.  # noqa: E501
        :rtype: AllOfInspectionCreateRequestInspectionCategory
        """
        return self._inspection_category

    @inspection_category.setter
    def inspection_category(self, inspection_category):
        """Sets the inspection_category of this InspectionCreateRequest.

        See business rules section 10.2 - Inspection types and categories  # noqa: E501

        :param inspection_category: The inspection_category of this InspectionCreateRequest.  # noqa: E501
        :type: AllOfInspectionCreateRequestInspectionCategory
        """

        self._inspection_category = inspection_category

    @property
    def inspection_outcome(self):
        """Gets the inspection_outcome of this InspectionCreateRequest.  # noqa: E501


        :return: The inspection_outcome of this InspectionCreateRequest.  # noqa: E501
        :rtype: InspectionOutcome
        """
        return self._inspection_outcome

    @inspection_outcome.setter
    def inspection_outcome(self, inspection_outcome):
        """Sets the inspection_outcome of this InspectionCreateRequest.


        :param inspection_outcome: The inspection_outcome of this InspectionCreateRequest.  # noqa: E501
        :type: InspectionOutcome
        """
        if inspection_outcome is None:
            raise ValueError("Invalid value for `inspection_outcome`, must not be `None`")  # noqa: E501

        self._inspection_outcome = inspection_outcome

    @property
    def failure_reason_details(self):
        """Gets the failure_reason_details of this InspectionCreateRequest.  # noqa: E501

        See business rules section 10.3 - Inspection outcomes  # noqa: E501

        :return: The failure_reason_details of this InspectionCreateRequest.  # noqa: E501
        :rtype: list[FailureReasonDetails]
        """
        return self._failure_reason_details

    @failure_reason_details.setter
    def failure_reason_details(self, failure_reason_details):
        """Sets the failure_reason_details of this InspectionCreateRequest.

        See business rules section 10.3 - Inspection outcomes  # noqa: E501

        :param failure_reason_details: The failure_reason_details of this InspectionCreateRequest.  # noqa: E501
        :type: list[FailureReasonDetails]
        """

        self._failure_reason_details = failure_reason_details

    @property
    def inspection_outcome_details(self):
        """Gets the inspection_outcome_details of this InspectionCreateRequest.  # noqa: E501

        Required if inspection_outcome = unable_to_complete_inspection or non_compliant_with_conditions Max length 500 characters  # noqa: E501

        :return: The inspection_outcome_details of this InspectionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._inspection_outcome_details

    @inspection_outcome_details.setter
    def inspection_outcome_details(self, inspection_outcome_details):
        """Sets the inspection_outcome_details of this InspectionCreateRequest.

        Required if inspection_outcome = unable_to_complete_inspection or non_compliant_with_conditions Max length 500 characters  # noqa: E501

        :param inspection_outcome_details: The inspection_outcome_details of this InspectionCreateRequest.  # noqa: E501
        :type: str
        """

        self._inspection_outcome_details = inspection_outcome_details

    @property
    def was_call_logged(self):
        """Gets the was_call_logged of this InspectionCreateRequest.  # noqa: E501

        Required if inspection_outcome = failed_high and inspection_type = live_site  # noqa: E501

        :return: The was_call_logged of this InspectionCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._was_call_logged

    @was_call_logged.setter
    def was_call_logged(self, was_call_logged):
        """Sets the was_call_logged of this InspectionCreateRequest.

        Required if inspection_outcome = failed_high and inspection_type = live_site  # noqa: E501

        :param was_call_logged: The was_call_logged of this InspectionCreateRequest.  # noqa: E501
        :type: bool
        """

        self._was_call_logged = was_call_logged

    @property
    def call_logged_to(self):
        """Gets the call_logged_to of this InspectionCreateRequest.  # noqa: E501

        Required if was_call_logged = true Max length 100 characters  # noqa: E501

        :return: The call_logged_to of this InspectionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._call_logged_to

    @call_logged_to.setter
    def call_logged_to(self, call_logged_to):
        """Sets the call_logged_to of this InspectionCreateRequest.

        Required if was_call_logged = true Max length 100 characters  # noqa: E501

        :param call_logged_to: The call_logged_to of this InspectionCreateRequest.  # noqa: E501
        :type: str
        """

        self._call_logged_to = call_logged_to

    @property
    def call_logged_reference(self):
        """Gets the call_logged_reference of this InspectionCreateRequest.  # noqa: E501

        Required if was_call_logged = true Max length 100 characters  # noqa: E501

        :return: The call_logged_reference of this InspectionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._call_logged_reference

    @call_logged_reference.setter
    def call_logged_reference(self, call_logged_reference):
        """Sets the call_logged_reference of this InspectionCreateRequest.

        Required if was_call_logged = true Max length 100 characters  # noqa: E501

        :param call_logged_reference: The call_logged_reference of this InspectionCreateRequest.  # noqa: E501
        :type: str
        """

        self._call_logged_reference = call_logged_reference

    @property
    def call_logged_summary(self):
        """Gets the call_logged_summary of this InspectionCreateRequest.  # noqa: E501

        Required if was_call_logged = true Max length 500 characters  # noqa: E501

        :return: The call_logged_summary of this InspectionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._call_logged_summary

    @call_logged_summary.setter
    def call_logged_summary(self, call_logged_summary):
        """Sets the call_logged_summary of this InspectionCreateRequest.

        Required if was_call_logged = true Max length 500 characters  # noqa: E501

        :param call_logged_summary: The call_logged_summary of this InspectionCreateRequest.  # noqa: E501
        :type: str
        """

        self._call_logged_summary = call_logged_summary

    @property
    def defect_fixed_on_site(self):
        """Gets the defect_fixed_on_site of this InspectionCreateRequest.  # noqa: E501

        Required if inspection_outcome = failed_high and inspection_type = live_site  # noqa: E501

        :return: The defect_fixed_on_site of this InspectionCreateRequest.  # noqa: E501
        :rtype: AllOfInspectionCreateRequestDefectFixedOnSite
        """
        return self._defect_fixed_on_site

    @defect_fixed_on_site.setter
    def defect_fixed_on_site(self, defect_fixed_on_site):
        """Sets the defect_fixed_on_site of this InspectionCreateRequest.

        Required if inspection_outcome = failed_high and inspection_type = live_site  # noqa: E501

        :param defect_fixed_on_site: The defect_fixed_on_site of this InspectionCreateRequest.  # noqa: E501
        :type: AllOfInspectionCreateRequestDefectFixedOnSite
        """

        self._defect_fixed_on_site = defect_fixed_on_site

    @property
    def additional_comments(self):
        """Gets the additional_comments of this InspectionCreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The additional_comments of this InspectionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._additional_comments

    @additional_comments.setter
    def additional_comments(self, additional_comments):
        """Sets the additional_comments of this InspectionCreateRequest.

        Max length 500 characters  # noqa: E501

        :param additional_comments: The additional_comments of this InspectionCreateRequest.  # noqa: E501
        :type: str
        """

        self._additional_comments = additional_comments

    @property
    def inspection_evidence(self):
        """Gets the inspection_evidence of this InspectionCreateRequest.  # noqa: E501


        :return: The inspection_evidence of this InspectionCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._inspection_evidence

    @inspection_evidence.setter
    def inspection_evidence(self, inspection_evidence):
        """Sets the inspection_evidence of this InspectionCreateRequest.


        :param inspection_evidence: The inspection_evidence of this InspectionCreateRequest.  # noqa: E501
        :type: bool
        """
        if inspection_evidence is None:
            raise ValueError("Invalid value for `inspection_evidence`, must not be `None`")  # noqa: E501

        self._inspection_evidence = inspection_evidence

    @property
    def file_ids(self):
        """Gets the file_ids of this InspectionCreateRequest.  # noqa: E501

        Required if inspection_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :return: The file_ids of this InspectionCreateRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._file_ids

    @file_ids.setter
    def file_ids(self, file_ids):
        """Sets the file_ids of this InspectionCreateRequest.

        Required if inspection_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :param file_ids: The file_ids of this InspectionCreateRequest.  # noqa: E501
        :type: list[float]
        """

        self._file_ids = file_ids

    @property
    def reinspection_date(self):
        """Gets the reinspection_date of this InspectionCreateRequest.  # noqa: E501

        Date must occur today or a date in the future  # noqa: E501

        :return: The reinspection_date of this InspectionCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._reinspection_date

    @reinspection_date.setter
    def reinspection_date(self, reinspection_date):
        """Sets the reinspection_date of this InspectionCreateRequest.

        Date must occur today or a date in the future  # noqa: E501

        :param reinspection_date: The reinspection_date of this InspectionCreateRequest.  # noqa: E501
        :type: datetime
        """

        self._reinspection_date = reinspection_date

    @property
    def reinspection_date_time(self):
        """Gets the reinspection_date_time of this InspectionCreateRequest.  # noqa: E501

        The date for reinspection_date_time must match the date for reinspection_date Time must occur today or a date in the future  # noqa: E501

        :return: The reinspection_date_time of this InspectionCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._reinspection_date_time

    @reinspection_date_time.setter
    def reinspection_date_time(self, reinspection_date_time):
        """Sets the reinspection_date_time of this InspectionCreateRequest.

        The date for reinspection_date_time must match the date for reinspection_date Time must occur today or a date in the future  # noqa: E501

        :param reinspection_date_time: The reinspection_date_time of this InspectionCreateRequest.  # noqa: E501
        :type: datetime
        """

        self._reinspection_date_time = reinspection_date_time

    @property
    def reinspection_type(self):
        """Gets the reinspection_type of this InspectionCreateRequest.  # noqa: E501

        Defaulted to inspection_type value if this and/or reinspection_category are not provided and reinspection_date is provided  # noqa: E501

        :return: The reinspection_type of this InspectionCreateRequest.  # noqa: E501
        :rtype: AllOfInspectionCreateRequestReinspectionType
        """
        return self._reinspection_type

    @reinspection_type.setter
    def reinspection_type(self, reinspection_type):
        """Sets the reinspection_type of this InspectionCreateRequest.

        Defaulted to inspection_type value if this and/or reinspection_category are not provided and reinspection_date is provided  # noqa: E501

        :param reinspection_type: The reinspection_type of this InspectionCreateRequest.  # noqa: E501
        :type: AllOfInspectionCreateRequestReinspectionType
        """

        self._reinspection_type = reinspection_type

    @property
    def reinspection_category(self):
        """Gets the reinspection_category of this InspectionCreateRequest.  # noqa: E501

        See business rules section 10.2 - Inspection types and categories Defaulted to inspection_category value if this and/or reinspection_type are not provided and reinspection_date is provided  # noqa: E501

        :return: The reinspection_category of this InspectionCreateRequest.  # noqa: E501
        :rtype: AllOfInspectionCreateRequestReinspectionCategory
        """
        return self._reinspection_category

    @reinspection_category.setter
    def reinspection_category(self, reinspection_category):
        """Sets the reinspection_category of this InspectionCreateRequest.

        See business rules section 10.2 - Inspection types and categories Defaulted to inspection_category value if this and/or reinspection_type are not provided and reinspection_date is provided  # noqa: E501

        :param reinspection_category: The reinspection_category of this InspectionCreateRequest.  # noqa: E501
        :type: AllOfInspectionCreateRequestReinspectionCategory
        """

        self._reinspection_category = reinspection_category

    @property
    def username(self):
        """Gets the username of this InspectionCreateRequest.  # noqa: E501

        Max length 100 characters Should be populated with the user creating the inspection  # noqa: E501

        :return: The username of this InspectionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this InspectionCreateRequest.

        Max length 100 characters Should be populated with the user creating the inspection  # noqa: E501

        :param username: The username of this InspectionCreateRequest.  # noqa: E501
        :type: str
        """
        if username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def inspector_name(self):
        """Gets the inspector_name of this InspectionCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The inspector_name of this InspectionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._inspector_name

    @inspector_name.setter
    def inspector_name(self, inspector_name):
        """Sets the inspector_name of this InspectionCreateRequest.

        Max length 100 characters  # noqa: E501

        :param inspector_name: The inspector_name of this InspectionCreateRequest.  # noqa: E501
        :type: str
        """

        self._inspector_name = inspector_name

    @property
    def made_safe_by_ha(self):
        """Gets the made_safe_by_ha of this InspectionCreateRequest.  # noqa: E501

        Required if inspection_type = section 81 and inspection_outcome = Failed - high or Failed - low  # noqa: E501

        :return: The made_safe_by_ha of this InspectionCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._made_safe_by_ha

    @made_safe_by_ha.setter
    def made_safe_by_ha(self, made_safe_by_ha):
        """Sets the made_safe_by_ha of this InspectionCreateRequest.

        Required if inspection_type = section 81 and inspection_outcome = Failed - high or Failed - low  # noqa: E501

        :param made_safe_by_ha: The made_safe_by_ha of this InspectionCreateRequest.  # noqa: E501
        :type: bool
        """

        self._made_safe_by_ha = made_safe_by_ha

    @property
    def non_compliance_reference_number(self):
        """Gets the non_compliance_reference_number of this InspectionCreateRequest.  # noqa: E501

        Max length 106 characters Created inspection will be linked to an existing non-compliance with this reference number inspection_type must be reinstatement or non_compliance_follow_up  # noqa: E501

        :return: The non_compliance_reference_number of this InspectionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._non_compliance_reference_number

    @non_compliance_reference_number.setter
    def non_compliance_reference_number(self, non_compliance_reference_number):
        """Sets the non_compliance_reference_number of this InspectionCreateRequest.

        Max length 106 characters Created inspection will be linked to an existing non-compliance with this reference number inspection_type must be reinstatement or non_compliance_follow_up  # noqa: E501

        :param non_compliance_reference_number: The non_compliance_reference_number of this InspectionCreateRequest.  # noqa: E501
        :type: str
        """

        self._non_compliance_reference_number = non_compliance_reference_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InspectionCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InspectionCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CommentResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment_reference_number': 'str',
        'comment_topic': 'CommentTopicResponse',
        'comment_topic_string': 'str',
        'detail': 'str',
        'author_email_address': 'str',
        'date_created': 'datetime',
        'is_read': 'bool',
        'read_by': 'str',
        'read_on': 'datetime',
        'is_internal': 'bool',
        'author_organisation_ref': 'str'
    }

    attribute_map = {
        'comment_reference_number': 'comment_reference_number',
        'comment_topic': 'comment_topic',
        'comment_topic_string': 'comment_topic_string',
        'detail': 'detail',
        'author_email_address': 'author_email_address',
        'date_created': 'date_created',
        'is_read': 'is_read',
        'read_by': 'read_by',
        'read_on': 'read_on',
        'is_internal': 'is_internal',
        'author_organisation_ref': 'author_organisation_ref'
    }

    def __init__(self, comment_reference_number=None, comment_topic=None, comment_topic_string=None, detail=None, author_email_address=None, date_created=None, is_read=None, read_by=None, read_on=None, is_internal=None, author_organisation_ref=None):  # noqa: E501
        """CommentResponse - a model defined in Swagger"""  # noqa: E501
        self._comment_reference_number = None
        self._comment_topic = None
        self._comment_topic_string = None
        self._detail = None
        self._author_email_address = None
        self._date_created = None
        self._is_read = None
        self._read_by = None
        self._read_on = None
        self._is_internal = None
        self._author_organisation_ref = None
        self.discriminator = None
        if comment_reference_number is not None:
            self.comment_reference_number = comment_reference_number
        self.comment_topic = comment_topic
        self.comment_topic_string = comment_topic_string
        self.detail = detail
        self.author_email_address = author_email_address
        self.date_created = date_created
        if is_read is not None:
            self.is_read = is_read
        if read_by is not None:
            self.read_by = read_by
        if read_on is not None:
            self.read_on = read_on
        if is_internal is not None:
            self.is_internal = is_internal
        if author_organisation_ref is not None:
            self.author_organisation_ref = author_organisation_ref

    @property
    def comment_reference_number(self):
        """Gets the comment_reference_number of this CommentResponse.  # noqa: E501


        :return: The comment_reference_number of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._comment_reference_number

    @comment_reference_number.setter
    def comment_reference_number(self, comment_reference_number):
        """Sets the comment_reference_number of this CommentResponse.


        :param comment_reference_number: The comment_reference_number of this CommentResponse.  # noqa: E501
        :type: str
        """

        self._comment_reference_number = comment_reference_number

    @property
    def comment_topic(self):
        """Gets the comment_topic of this CommentResponse.  # noqa: E501


        :return: The comment_topic of this CommentResponse.  # noqa: E501
        :rtype: CommentTopicResponse
        """
        return self._comment_topic

    @comment_topic.setter
    def comment_topic(self, comment_topic):
        """Sets the comment_topic of this CommentResponse.


        :param comment_topic: The comment_topic of this CommentResponse.  # noqa: E501
        :type: CommentTopicResponse
        """
        if comment_topic is None:
            raise ValueError("Invalid value for `comment_topic`, must not be `None`")  # noqa: E501

        self._comment_topic = comment_topic

    @property
    def comment_topic_string(self):
        """Gets the comment_topic_string of this CommentResponse.  # noqa: E501


        :return: The comment_topic_string of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._comment_topic_string

    @comment_topic_string.setter
    def comment_topic_string(self, comment_topic_string):
        """Sets the comment_topic_string of this CommentResponse.


        :param comment_topic_string: The comment_topic_string of this CommentResponse.  # noqa: E501
        :type: str
        """
        if comment_topic_string is None:
            raise ValueError("Invalid value for `comment_topic_string`, must not be `None`")  # noqa: E501

        self._comment_topic_string = comment_topic_string

    @property
    def detail(self):
        """Gets the detail of this CommentResponse.  # noqa: E501


        :return: The detail of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this CommentResponse.


        :param detail: The detail of this CommentResponse.  # noqa: E501
        :type: str
        """
        if detail is None:
            raise ValueError("Invalid value for `detail`, must not be `None`")  # noqa: E501

        self._detail = detail

    @property
    def author_email_address(self):
        """Gets the author_email_address of this CommentResponse.  # noqa: E501


        :return: The author_email_address of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._author_email_address

    @author_email_address.setter
    def author_email_address(self, author_email_address):
        """Sets the author_email_address of this CommentResponse.


        :param author_email_address: The author_email_address of this CommentResponse.  # noqa: E501
        :type: str
        """
        if author_email_address is None:
            raise ValueError("Invalid value for `author_email_address`, must not be `None`")  # noqa: E501

        self._author_email_address = author_email_address

    @property
    def date_created(self):
        """Gets the date_created of this CommentResponse.  # noqa: E501


        :return: The date_created of this CommentResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this CommentResponse.


        :param date_created: The date_created of this CommentResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def is_read(self):
        """Gets the is_read of this CommentResponse.  # noqa: E501


        :return: The is_read of this CommentResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_read

    @is_read.setter
    def is_read(self, is_read):
        """Sets the is_read of this CommentResponse.


        :param is_read: The is_read of this CommentResponse.  # noqa: E501
        :type: bool
        """

        self._is_read = is_read

    @property
    def read_by(self):
        """Gets the read_by of this CommentResponse.  # noqa: E501


        :return: The read_by of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._read_by

    @read_by.setter
    def read_by(self, read_by):
        """Sets the read_by of this CommentResponse.


        :param read_by: The read_by of this CommentResponse.  # noqa: E501
        :type: str
        """

        self._read_by = read_by

    @property
    def read_on(self):
        """Gets the read_on of this CommentResponse.  # noqa: E501


        :return: The read_on of this CommentResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._read_on

    @read_on.setter
    def read_on(self, read_on):
        """Sets the read_on of this CommentResponse.


        :param read_on: The read_on of this CommentResponse.  # noqa: E501
        :type: datetime
        """

        self._read_on = read_on

    @property
    def is_internal(self):
        """Gets the is_internal of this CommentResponse.  # noqa: E501


        :return: The is_internal of this CommentResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_internal

    @is_internal.setter
    def is_internal(self, is_internal):
        """Sets the is_internal of this CommentResponse.


        :param is_internal: The is_internal of this CommentResponse.  # noqa: E501
        :type: bool
        """

        self._is_internal = is_internal

    @property
    def author_organisation_ref(self):
        """Gets the author_organisation_ref of this CommentResponse.  # noqa: E501


        :return: The author_organisation_ref of this CommentResponse.  # noqa: E501
        :rtype: str
        """
        return self._author_organisation_ref

    @author_organisation_ref.setter
    def author_organisation_ref(self, author_organisation_ref):
        """Sets the author_organisation_ref of this CommentResponse.


        :param author_organisation_ref: The author_organisation_ref of this CommentResponse.  # noqa: E501
        :type: str
        """

        self._author_organisation_ref = author_organisation_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CommentResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager GeoJSON API

    See API specification Resource Guide > GeoJSON API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ForwardPlanProperties(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'forward_plan_reference_number': 'str',
        'work_reference_number': 'str',
        'forward_plan_status': 'ForwardPlanStatusResponse',
        'forward_plan_status_string': 'str',
        'work_centre_point': 'GeoJSONCentrePoint',
        'street': 'str',
        'area': 'str',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'description_of_work': 'str',
        'promoter_organisation': 'str',
        'location_description': 'str'
    }

    attribute_map = {
        'forward_plan_reference_number': 'forward_plan_reference_number',
        'work_reference_number': 'work_reference_number',
        'forward_plan_status': 'forward_plan_status',
        'forward_plan_status_string': 'forward_plan_status_string',
        'work_centre_point': 'work_centre_point',
        'street': 'street',
        'area': 'area',
        'start_date': 'start_date',
        'end_date': 'end_date',
        'description_of_work': 'description_of_work',
        'promoter_organisation': 'promoter_organisation',
        'location_description': 'location_description'
    }

    def __init__(self, forward_plan_reference_number=None, work_reference_number=None, forward_plan_status=None, forward_plan_status_string=None, work_centre_point=None, street=None, area=None, start_date=None, end_date=None, description_of_work=None, promoter_organisation=None, location_description=None):  # noqa: E501
        """ForwardPlanProperties - a model defined in Swagger"""  # noqa: E501
        self._forward_plan_reference_number = None
        self._work_reference_number = None
        self._forward_plan_status = None
        self._forward_plan_status_string = None
        self._work_centre_point = None
        self._street = None
        self._area = None
        self._start_date = None
        self._end_date = None
        self._description_of_work = None
        self._promoter_organisation = None
        self._location_description = None
        self.discriminator = None
        self.forward_plan_reference_number = forward_plan_reference_number
        self.work_reference_number = work_reference_number
        self.forward_plan_status = forward_plan_status
        self.forward_plan_status_string = forward_plan_status_string
        self.work_centre_point = work_centre_point
        self.street = street
        if area is not None:
            self.area = area
        self.start_date = start_date
        self.end_date = end_date
        self.description_of_work = description_of_work
        self.promoter_organisation = promoter_organisation
        self.location_description = location_description

    @property
    def forward_plan_reference_number(self):
        """Gets the forward_plan_reference_number of this ForwardPlanProperties.  # noqa: E501


        :return: The forward_plan_reference_number of this ForwardPlanProperties.  # noqa: E501
        :rtype: str
        """
        return self._forward_plan_reference_number

    @forward_plan_reference_number.setter
    def forward_plan_reference_number(self, forward_plan_reference_number):
        """Sets the forward_plan_reference_number of this ForwardPlanProperties.


        :param forward_plan_reference_number: The forward_plan_reference_number of this ForwardPlanProperties.  # noqa: E501
        :type: str
        """
        if forward_plan_reference_number is None:
            raise ValueError("Invalid value for `forward_plan_reference_number`, must not be `None`")  # noqa: E501

        self._forward_plan_reference_number = forward_plan_reference_number

    @property
    def work_reference_number(self):
        """Gets the work_reference_number of this ForwardPlanProperties.  # noqa: E501


        :return: The work_reference_number of this ForwardPlanProperties.  # noqa: E501
        :rtype: str
        """
        return self._work_reference_number

    @work_reference_number.setter
    def work_reference_number(self, work_reference_number):
        """Sets the work_reference_number of this ForwardPlanProperties.


        :param work_reference_number: The work_reference_number of this ForwardPlanProperties.  # noqa: E501
        :type: str
        """
        if work_reference_number is None:
            raise ValueError("Invalid value for `work_reference_number`, must not be `None`")  # noqa: E501

        self._work_reference_number = work_reference_number

    @property
    def forward_plan_status(self):
        """Gets the forward_plan_status of this ForwardPlanProperties.  # noqa: E501


        :return: The forward_plan_status of this ForwardPlanProperties.  # noqa: E501
        :rtype: ForwardPlanStatusResponse
        """
        return self._forward_plan_status

    @forward_plan_status.setter
    def forward_plan_status(self, forward_plan_status):
        """Sets the forward_plan_status of this ForwardPlanProperties.


        :param forward_plan_status: The forward_plan_status of this ForwardPlanProperties.  # noqa: E501
        :type: ForwardPlanStatusResponse
        """
        if forward_plan_status is None:
            raise ValueError("Invalid value for `forward_plan_status`, must not be `None`")  # noqa: E501

        self._forward_plan_status = forward_plan_status

    @property
    def forward_plan_status_string(self):
        """Gets the forward_plan_status_string of this ForwardPlanProperties.  # noqa: E501


        :return: The forward_plan_status_string of this ForwardPlanProperties.  # noqa: E501
        :rtype: str
        """
        return self._forward_plan_status_string

    @forward_plan_status_string.setter
    def forward_plan_status_string(self, forward_plan_status_string):
        """Sets the forward_plan_status_string of this ForwardPlanProperties.


        :param forward_plan_status_string: The forward_plan_status_string of this ForwardPlanProperties.  # noqa: E501
        :type: str
        """
        if forward_plan_status_string is None:
            raise ValueError("Invalid value for `forward_plan_status_string`, must not be `None`")  # noqa: E501

        self._forward_plan_status_string = forward_plan_status_string

    @property
    def work_centre_point(self):
        """Gets the work_centre_point of this ForwardPlanProperties.  # noqa: E501


        :return: The work_centre_point of this ForwardPlanProperties.  # noqa: E501
        :rtype: GeoJSONCentrePoint
        """
        return self._work_centre_point

    @work_centre_point.setter
    def work_centre_point(self, work_centre_point):
        """Sets the work_centre_point of this ForwardPlanProperties.


        :param work_centre_point: The work_centre_point of this ForwardPlanProperties.  # noqa: E501
        :type: GeoJSONCentrePoint
        """
        if work_centre_point is None:
            raise ValueError("Invalid value for `work_centre_point`, must not be `None`")  # noqa: E501

        self._work_centre_point = work_centre_point

    @property
    def street(self):
        """Gets the street of this ForwardPlanProperties.  # noqa: E501


        :return: The street of this ForwardPlanProperties.  # noqa: E501
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """Sets the street of this ForwardPlanProperties.


        :param street: The street of this ForwardPlanProperties.  # noqa: E501
        :type: str
        """
        if street is None:
            raise ValueError("Invalid value for `street`, must not be `None`")  # noqa: E501

        self._street = street

    @property
    def area(self):
        """Gets the area of this ForwardPlanProperties.  # noqa: E501


        :return: The area of this ForwardPlanProperties.  # noqa: E501
        :rtype: str
        """
        return self._area

    @area.setter
    def area(self, area):
        """Sets the area of this ForwardPlanProperties.


        :param area: The area of this ForwardPlanProperties.  # noqa: E501
        :type: str
        """

        self._area = area

    @property
    def start_date(self):
        """Gets the start_date of this ForwardPlanProperties.  # noqa: E501


        :return: The start_date of this ForwardPlanProperties.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ForwardPlanProperties.


        :param start_date: The start_date of this ForwardPlanProperties.  # noqa: E501
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this ForwardPlanProperties.  # noqa: E501


        :return: The end_date of this ForwardPlanProperties.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ForwardPlanProperties.


        :param end_date: The end_date of this ForwardPlanProperties.  # noqa: E501
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def description_of_work(self):
        """Gets the description_of_work of this ForwardPlanProperties.  # noqa: E501


        :return: The description_of_work of this ForwardPlanProperties.  # noqa: E501
        :rtype: str
        """
        return self._description_of_work

    @description_of_work.setter
    def description_of_work(self, description_of_work):
        """Sets the description_of_work of this ForwardPlanProperties.


        :param description_of_work: The description_of_work of this ForwardPlanProperties.  # noqa: E501
        :type: str
        """
        if description_of_work is None:
            raise ValueError("Invalid value for `description_of_work`, must not be `None`")  # noqa: E501

        self._description_of_work = description_of_work

    @property
    def promoter_organisation(self):
        """Gets the promoter_organisation of this ForwardPlanProperties.  # noqa: E501


        :return: The promoter_organisation of this ForwardPlanProperties.  # noqa: E501
        :rtype: str
        """
        return self._promoter_organisation

    @promoter_organisation.setter
    def promoter_organisation(self, promoter_organisation):
        """Sets the promoter_organisation of this ForwardPlanProperties.


        :param promoter_organisation: The promoter_organisation of this ForwardPlanProperties.  # noqa: E501
        :type: str
        """
        if promoter_organisation is None:
            raise ValueError("Invalid value for `promoter_organisation`, must not be `None`")  # noqa: E501

        self._promoter_organisation = promoter_organisation

    @property
    def location_description(self):
        """Gets the location_description of this ForwardPlanProperties.  # noqa: E501


        :return: The location_description of this ForwardPlanProperties.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this ForwardPlanProperties.


        :param location_description: The location_description of this ForwardPlanProperties.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ForwardPlanProperties, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ForwardPlanProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FailureReason(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    LIVE_SITE_SIGNAGE = "live_site_signage"
    LIVE_SITE_DISTANCE = "live_site_distance"
    LIVE_SITE_SAFETY_ZONE = "live_site_safety_zone"
    LIVE_SITE_BARRIERS = "live_site_barriers"
    LIVE_SITE_TRAFFIC_CONTROL = "live_site_traffic_control"
    LIVE_SITE_PEDESTRIAN_PROVISION = "live_site_pedestrian_provision"
    LIVE_SITE_CYCLIST_PROVISION = "live_site_cyclist_provision"
    LIVE_SITE_OPERATIVE_QUALIFICATION = "live_site_operative_qualification"
    LIVE_SITE_EQUIPMENT = "live_site_equipment"
    LIVE_SITE_MATERIALS = "live_site_materials"
    LIVE_SITE_COMPACTION = "live_site_compaction"
    LIVE_SITE_CONSTRUCTION_LAYERS = "live_site_construction_layers"
    LIVE_SITE_STORAGE_OF_MATERIALS = "live_site_storage_of_materials"
    REINSTATEMENT_DAMAGE_TO_SURROUND_AREA = "reinstatement_damage_to_surround_area"
    REINSTATEMENT_SAW_CUTTING = "reinstatement_saw_cutting"
    REINSTATEMENT_ACUTE_ANGLES = "reinstatement_acute_angles"
    REINSTATEMENT_VERGE = "reinstatement_verge"
    REINSTATEMENT_ANTI_SKID = "reinstatement_anti_skid"
    REINSTATEMENT_FIXED_FEATURES = "reinstatement_fixed_features"
    REINSTATEMENT_MODULAR = "reinstatement_modular"
    REINSTATEMENT_PROXIMITY = "reinstatement_proximity"
    REINSTATEMENT_MATERIALS_INCORRECT = "reinstatement_materials_incorrect"
    REINSTATEMENT_MATERIALS_DAMAGED = "reinstatement_materials_damaged"
    REINSTATEMENT_EDGE_SEALANT = "reinstatement_edge_sealant"
    REINSTATEMENT_OVER_BANDING = "reinstatement_over_banding"
    REINSTATEMENT_ROAD_MARKINGS = "reinstatement_road_markings"
    REINSTATEMENT_INFILL_POINTING = "reinstatement_infill_pointing"
    REINSTATEMENT_IRONWORK_APPARATUS = "reinstatement_ironwork_apparatus"
    REINSTATEMENT_BREAKING_OUT_FRETTING = "reinstatement_breaking_out_fretting"
    REINSTATEMENT_INTERFACE_CRACKING = "reinstatement_interface_cracking"
    REINSTATEMENT_CROWNING = "reinstatement_crowning"
    REINSTATEMENT_DEPRESSION = "reinstatement_depression"
    REINSTATEMENT_AS_LAID_PROFILE = "reinstatement_as_laid_profile"
    REINSTATEMENT_TEXTURE_DEPTH = "reinstatement_texture_depth"
    REINSTATEMENT_EDGE_DEPRESSION = "reinstatement_edge_depression"
    INVESTIGATORY_AIR_VOID = "investigatory_air_void"
    INVESTIGATORY_MATERIAL_TYPE = "investigatory_material_type"
    INVESTIGATORY_LAYER_DEPTH = "investigatory_layer_depth"
    INVESTIGATORY_CONTAMINATION = "investigatory_contamination"
    INVESTIGATORY_OTHER = "investigatory_other"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """FailureReason - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FailureReason, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FailureReason):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DurationCalculationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'calendar_days': 'float',
        'working_days': 'float'
    }

    attribute_map = {
        'calendar_days': 'calendar_days',
        'working_days': 'working_days'
    }

    def __init__(self, calendar_days=None, working_days=None):  # noqa: E501
        """DurationCalculationResponse - a model defined in Swagger"""  # noqa: E501
        self._calendar_days = None
        self._working_days = None
        self.discriminator = None
        self.calendar_days = calendar_days
        self.working_days = working_days

    @property
    def calendar_days(self):
        """Gets the calendar_days of this DurationCalculationResponse.  # noqa: E501


        :return: The calendar_days of this DurationCalculationResponse.  # noqa: E501
        :rtype: float
        """
        return self._calendar_days

    @calendar_days.setter
    def calendar_days(self, calendar_days):
        """Sets the calendar_days of this DurationCalculationResponse.


        :param calendar_days: The calendar_days of this DurationCalculationResponse.  # noqa: E501
        :type: float
        """
        if calendar_days is None:
            raise ValueError("Invalid value for `calendar_days`, must not be `None`")  # noqa: E501

        self._calendar_days = calendar_days

    @property
    def working_days(self):
        """Gets the working_days of this DurationCalculationResponse.  # noqa: E501


        :return: The working_days of this DurationCalculationResponse.  # noqa: E501
        :rtype: float
        """
        return self._working_days

    @working_days.setter
    def working_days(self, working_days):
        """Sets the working_days of this DurationCalculationResponse.


        :param working_days: The working_days of this DurationCalculationResponse.  # noqa: E501
        :type: float
        """
        if working_days is None:
            raise ValueError("Invalid value for `working_days`, must not be `None`")  # noqa: E501

        self._working_days = working_days

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DurationCalculationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DurationCalculationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Section74CreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'permit_reference_number': 'str',
        'location_description': 'str',
        'location_types': 'list[LocationType]',
        'inspection_date': 'datetime',
        'overrun_warning_reasons': 'list[OverrunWarningReason]',
        'overrun_warning_details': 'str',
        'officer_name': 'str',
        'officer_contact_details': 'str',
        'schedule_follow_up_inspection': 'bool',
        'reinspection_date': 'datetime',
        'reinspection_date_time': 'datetime',
        'section_74_evidence': 'bool',
        'file_ids': 'list[float]'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'permit_reference_number': 'permit_reference_number',
        'location_description': 'location_description',
        'location_types': 'location_types',
        'inspection_date': 'inspection_date',
        'overrun_warning_reasons': 'overrun_warning_reasons',
        'overrun_warning_details': 'overrun_warning_details',
        'officer_name': 'officer_name',
        'officer_contact_details': 'officer_contact_details',
        'schedule_follow_up_inspection': 'schedule_follow_up_inspection',
        'reinspection_date': 'reinspection_date',
        'reinspection_date_time': 'reinspection_date_time',
        'section_74_evidence': 'section_74_evidence',
        'file_ids': 'file_ids'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, permit_reference_number=None, location_description=None, location_types=None, inspection_date=None, overrun_warning_reasons=None, overrun_warning_details=None, officer_name=None, officer_contact_details=None, schedule_follow_up_inspection=None, reinspection_date=None, reinspection_date_time=None, section_74_evidence=None, file_ids=None):  # noqa: E501
        """Section74CreateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._permit_reference_number = None
        self._location_description = None
        self._location_types = None
        self._inspection_date = None
        self._overrun_warning_reasons = None
        self._overrun_warning_details = None
        self._officer_name = None
        self._officer_contact_details = None
        self._schedule_follow_up_inspection = None
        self._reinspection_date = None
        self._reinspection_date_time = None
        self._section_74_evidence = None
        self._file_ids = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.permit_reference_number = permit_reference_number
        self.location_description = location_description
        self.location_types = location_types
        self.inspection_date = inspection_date
        self.overrun_warning_reasons = overrun_warning_reasons
        self.overrun_warning_details = overrun_warning_details
        self.officer_name = officer_name
        self.officer_contact_details = officer_contact_details
        self.schedule_follow_up_inspection = schedule_follow_up_inspection
        if reinspection_date is not None:
            self.reinspection_date = reinspection_date
        if reinspection_date_time is not None:
            self.reinspection_date_time = reinspection_date_time
        self.section_74_evidence = section_74_evidence
        if file_ids is not None:
            self.file_ids = file_ids

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this Section74CreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this Section74CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this Section74CreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this Section74CreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this Section74CreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this Section74CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this Section74CreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this Section74CreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def permit_reference_number(self):
        """Gets the permit_reference_number of this Section74CreateRequest.  # noqa: E501


        :return: The permit_reference_number of this Section74CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._permit_reference_number

    @permit_reference_number.setter
    def permit_reference_number(self, permit_reference_number):
        """Sets the permit_reference_number of this Section74CreateRequest.


        :param permit_reference_number: The permit_reference_number of this Section74CreateRequest.  # noqa: E501
        :type: str
        """
        if permit_reference_number is None:
            raise ValueError("Invalid value for `permit_reference_number`, must not be `None`")  # noqa: E501

        self._permit_reference_number = permit_reference_number

    @property
    def location_description(self):
        """Gets the location_description of this Section74CreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The location_description of this Section74CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this Section74CreateRequest.

        Max length 500 characters  # noqa: E501

        :param location_description: The location_description of this Section74CreateRequest.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    @property
    def location_types(self):
        """Gets the location_types of this Section74CreateRequest.  # noqa: E501

        Array values must be unique  # noqa: E501

        :return: The location_types of this Section74CreateRequest.  # noqa: E501
        :rtype: list[LocationType]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this Section74CreateRequest.

        Array values must be unique  # noqa: E501

        :param location_types: The location_types of this Section74CreateRequest.  # noqa: E501
        :type: list[LocationType]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def inspection_date(self):
        """Gets the inspection_date of this Section74CreateRequest.  # noqa: E501

        Date must be today or a date in the past  # noqa: E501

        :return: The inspection_date of this Section74CreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._inspection_date

    @inspection_date.setter
    def inspection_date(self, inspection_date):
        """Sets the inspection_date of this Section74CreateRequest.

        Date must be today or a date in the past  # noqa: E501

        :param inspection_date: The inspection_date of this Section74CreateRequest.  # noqa: E501
        :type: datetime
        """
        if inspection_date is None:
            raise ValueError("Invalid value for `inspection_date`, must not be `None`")  # noqa: E501

        self._inspection_date = inspection_date

    @property
    def overrun_warning_reasons(self):
        """Gets the overrun_warning_reasons of this Section74CreateRequest.  # noqa: E501

        Array values must be unique  # noqa: E501

        :return: The overrun_warning_reasons of this Section74CreateRequest.  # noqa: E501
        :rtype: list[OverrunWarningReason]
        """
        return self._overrun_warning_reasons

    @overrun_warning_reasons.setter
    def overrun_warning_reasons(self, overrun_warning_reasons):
        """Sets the overrun_warning_reasons of this Section74CreateRequest.

        Array values must be unique  # noqa: E501

        :param overrun_warning_reasons: The overrun_warning_reasons of this Section74CreateRequest.  # noqa: E501
        :type: list[OverrunWarningReason]
        """
        if overrun_warning_reasons is None:
            raise ValueError("Invalid value for `overrun_warning_reasons`, must not be `None`")  # noqa: E501

        self._overrun_warning_reasons = overrun_warning_reasons

    @property
    def overrun_warning_details(self):
        """Gets the overrun_warning_details of this Section74CreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The overrun_warning_details of this Section74CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._overrun_warning_details

    @overrun_warning_details.setter
    def overrun_warning_details(self, overrun_warning_details):
        """Sets the overrun_warning_details of this Section74CreateRequest.

        Max length 500 characters  # noqa: E501

        :param overrun_warning_details: The overrun_warning_details of this Section74CreateRequest.  # noqa: E501
        :type: str
        """
        if overrun_warning_details is None:
            raise ValueError("Invalid value for `overrun_warning_details`, must not be `None`")  # noqa: E501

        self._overrun_warning_details = overrun_warning_details

    @property
    def officer_name(self):
        """Gets the officer_name of this Section74CreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The officer_name of this Section74CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._officer_name

    @officer_name.setter
    def officer_name(self, officer_name):
        """Sets the officer_name of this Section74CreateRequest.

        Max length 100 characters  # noqa: E501

        :param officer_name: The officer_name of this Section74CreateRequest.  # noqa: E501
        :type: str
        """
        if officer_name is None:
            raise ValueError("Invalid value for `officer_name`, must not be `None`")  # noqa: E501

        self._officer_name = officer_name

    @property
    def officer_contact_details(self):
        """Gets the officer_contact_details of this Section74CreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The officer_contact_details of this Section74CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._officer_contact_details

    @officer_contact_details.setter
    def officer_contact_details(self, officer_contact_details):
        """Sets the officer_contact_details of this Section74CreateRequest.

        Max length 100 characters  # noqa: E501

        :param officer_contact_details: The officer_contact_details of this Section74CreateRequest.  # noqa: E501
        :type: str
        """
        if officer_contact_details is None:
            raise ValueError("Invalid value for `officer_contact_details`, must not be `None`")  # noqa: E501

        self._officer_contact_details = officer_contact_details

    @property
    def schedule_follow_up_inspection(self):
        """Gets the schedule_follow_up_inspection of this Section74CreateRequest.  # noqa: E501


        :return: The schedule_follow_up_inspection of this Section74CreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._schedule_follow_up_inspection

    @schedule_follow_up_inspection.setter
    def schedule_follow_up_inspection(self, schedule_follow_up_inspection):
        """Sets the schedule_follow_up_inspection of this Section74CreateRequest.


        :param schedule_follow_up_inspection: The schedule_follow_up_inspection of this Section74CreateRequest.  # noqa: E501
        :type: bool
        """
        if schedule_follow_up_inspection is None:
            raise ValueError("Invalid value for `schedule_follow_up_inspection`, must not be `None`")  # noqa: E501

        self._schedule_follow_up_inspection = schedule_follow_up_inspection

    @property
    def reinspection_date(self):
        """Gets the reinspection_date of this Section74CreateRequest.  # noqa: E501

        Date must occur today or a date in the future  # noqa: E501

        :return: The reinspection_date of this Section74CreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._reinspection_date

    @reinspection_date.setter
    def reinspection_date(self, reinspection_date):
        """Sets the reinspection_date of this Section74CreateRequest.

        Date must occur today or a date in the future  # noqa: E501

        :param reinspection_date: The reinspection_date of this Section74CreateRequest.  # noqa: E501
        :type: datetime
        """

        self._reinspection_date = reinspection_date

    @property
    def reinspection_date_time(self):
        """Gets the reinspection_date_time of this Section74CreateRequest.  # noqa: E501

        The date for reinspection_date_time must match the date for reinspection_date Time must occur today or a date in the future  # noqa: E501

        :return: The reinspection_date_time of this Section74CreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._reinspection_date_time

    @reinspection_date_time.setter
    def reinspection_date_time(self, reinspection_date_time):
        """Sets the reinspection_date_time of this Section74CreateRequest.

        The date for reinspection_date_time must match the date for reinspection_date Time must occur today or a date in the future  # noqa: E501

        :param reinspection_date_time: The reinspection_date_time of this Section74CreateRequest.  # noqa: E501
        :type: datetime
        """

        self._reinspection_date_time = reinspection_date_time

    @property
    def section_74_evidence(self):
        """Gets the section_74_evidence of this Section74CreateRequest.  # noqa: E501


        :return: The section_74_evidence of this Section74CreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._section_74_evidence

    @section_74_evidence.setter
    def section_74_evidence(self, section_74_evidence):
        """Sets the section_74_evidence of this Section74CreateRequest.


        :param section_74_evidence: The section_74_evidence of this Section74CreateRequest.  # noqa: E501
        :type: bool
        """
        if section_74_evidence is None:
            raise ValueError("Invalid value for `section_74_evidence`, must not be `None`")  # noqa: E501

        self._section_74_evidence = section_74_evidence

    @property
    def file_ids(self):
        """Gets the file_ids of this Section74CreateRequest.  # noqa: E501

        Required if section_74_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :return: The file_ids of this Section74CreateRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._file_ids

    @file_ids.setter
    def file_ids(self, file_ids):
        """Sets the file_ids of this Section74CreateRequest.

        Required if section_74_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :param file_ids: The file_ids of this Section74CreateRequest.  # noqa: E501
        :type: list[float]
        """

        self._file_ids = file_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Section74CreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Section74CreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager GeoJSON API

    See API specification Resource Guide > GeoJSON API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityFeature(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'FeatureType',
        'geometry': 'GeoJSONGeometry',
        'properties': 'ActivityProperties'
    }

    attribute_map = {
        'type': 'type',
        'geometry': 'geometry',
        'properties': 'properties'
    }

    def __init__(self, type=None, geometry=None, properties=None):  # noqa: E501
        """ActivityFeature - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._geometry = None
        self._properties = None
        self.discriminator = None
        self.type = type
        self.geometry = geometry
        self.properties = properties

    @property
    def type(self):
        """Gets the type of this ActivityFeature.  # noqa: E501


        :return: The type of this ActivityFeature.  # noqa: E501
        :rtype: FeatureType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ActivityFeature.


        :param type: The type of this ActivityFeature.  # noqa: E501
        :type: FeatureType
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def geometry(self):
        """Gets the geometry of this ActivityFeature.  # noqa: E501


        :return: The geometry of this ActivityFeature.  # noqa: E501
        :rtype: GeoJSONGeometry
        """
        return self._geometry

    @geometry.setter
    def geometry(self, geometry):
        """Sets the geometry of this ActivityFeature.


        :param geometry: The geometry of this ActivityFeature.  # noqa: E501
        :type: GeoJSONGeometry
        """
        if geometry is None:
            raise ValueError("Invalid value for `geometry`, must not be `None`")  # noqa: E501

        self._geometry = geometry

    @property
    def properties(self):
        """Gets the properties of this ActivityFeature.  # noqa: E501


        :return: The properties of this ActivityFeature.  # noqa: E501
        :rtype: ActivityProperties
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this ActivityFeature.


        :param properties: The properties of this ActivityFeature.  # noqa: E501
        :type: ActivityProperties
        """
        if properties is None:
            raise ValueError("Invalid value for `properties`, must not be `None`")  # noqa: E501

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityFeature, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityFeature):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InspectionSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'inspection_date': 'datetime',
        'inspection_response_type': 'InspectionResponseTypeResponse',
        'inspection_response_type_string': 'str',
        'inspection_reference_number': 'str',
        'inspection_type': 'InspectionTypeResponse',
        'inspection_type_string': 'str',
        'inspection_status': 'InspectionStatusResponse',
        'inspection_status_string': 'str',
        'inspection_category': 'AllOfInspectionSummaryResponseInspectionCategory',
        'inspection_category_string': 'str',
        'inspection_outcome': 'AllOfInspectionSummaryResponseInspectionOutcome',
        'inspection_outcome_string': 'str',
        'reinspection_date_time': 'datetime',
        'auto_acceptance_due_date': 'datetime',
        'ha_response_status': 'InspectionOutcomeStatusTypeResponse',
        'ha_response_status_string': 'str',
        'ha_response_status_change_date': 'datetime',
        'ha_response_details': 'str',
        'promoter_response_status': 'InspectionOutcomeStatusTypeResponse',
        'promoter_response_status_string': 'str',
        'promoter_response_status_change_date': 'datetime',
        'promoter_response_details': 'str',
        'is_auto_accepted': 'bool',
        'non_compliance_reference_number': 'str'
    }

    attribute_map = {
        'inspection_date': 'inspection_date',
        'inspection_response_type': 'inspection_response_type',
        'inspection_response_type_string': 'inspection_response_type_string',
        'inspection_reference_number': 'inspection_reference_number',
        'inspection_type': 'inspection_type',
        'inspection_type_string': 'inspection_type_string',
        'inspection_status': 'inspection_status',
        'inspection_status_string': 'inspection_status_string',
        'inspection_category': 'inspection_category',
        'inspection_category_string': 'inspection_category_string',
        'inspection_outcome': 'inspection_outcome',
        'inspection_outcome_string': 'inspection_outcome_string',
        'reinspection_date_time': 'reinspection_date_time',
        'auto_acceptance_due_date': 'auto_acceptance_due_date',
        'ha_response_status': 'ha_response_status',
        'ha_response_status_string': 'ha_response_status_string',
        'ha_response_status_change_date': 'ha_response_status_change_date',
        'ha_response_details': 'ha_response_details',
        'promoter_response_status': 'promoter_response_status',
        'promoter_response_status_string': 'promoter_response_status_string',
        'promoter_response_status_change_date': 'promoter_response_status_change_date',
        'promoter_response_details': 'promoter_response_details',
        'is_auto_accepted': 'is_auto_accepted',
        'non_compliance_reference_number': 'non_compliance_reference_number'
    }

    def __init__(self, inspection_date=None, inspection_response_type=None, inspection_response_type_string=None, inspection_reference_number=None, inspection_type=None, inspection_type_string=None, inspection_status=None, inspection_status_string=None, inspection_category=None, inspection_category_string=None, inspection_outcome=None, inspection_outcome_string=None, reinspection_date_time=None, auto_acceptance_due_date=None, ha_response_status=None, ha_response_status_string=None, ha_response_status_change_date=None, ha_response_details=None, promoter_response_status=None, promoter_response_status_string=None, promoter_response_status_change_date=None, promoter_response_details=None, is_auto_accepted=None, non_compliance_reference_number=None):  # noqa: E501
        """InspectionSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._inspection_date = None
        self._inspection_response_type = None
        self._inspection_response_type_string = None
        self._inspection_reference_number = None
        self._inspection_type = None
        self._inspection_type_string = None
        self._inspection_status = None
        self._inspection_status_string = None
        self._inspection_category = None
        self._inspection_category_string = None
        self._inspection_outcome = None
        self._inspection_outcome_string = None
        self._reinspection_date_time = None
        self._auto_acceptance_due_date = None
        self._ha_response_status = None
        self._ha_response_status_string = None
        self._ha_response_status_change_date = None
        self._ha_response_details = None
        self._promoter_response_status = None
        self._promoter_response_status_string = None
        self._promoter_response_status_change_date = None
        self._promoter_response_details = None
        self._is_auto_accepted = None
        self._non_compliance_reference_number = None
        self.discriminator = None
        self.inspection_date = inspection_date
        self.inspection_response_type = inspection_response_type
        self.inspection_response_type_string = inspection_response_type_string
        if inspection_reference_number is not None:
            self.inspection_reference_number = inspection_reference_number
        self.inspection_type = inspection_type
        self.inspection_type_string = inspection_type_string
        self.inspection_status = inspection_status
        self.inspection_status_string = inspection_status_string
        if inspection_category is not None:
            self.inspection_category = inspection_category
        if inspection_category_string is not None:
            self.inspection_category_string = inspection_category_string
        if inspection_outcome is not None:
            self.inspection_outcome = inspection_outcome
        if inspection_outcome_string is not None:
            self.inspection_outcome_string = inspection_outcome_string
        if reinspection_date_time is not None:
            self.reinspection_date_time = reinspection_date_time
        if auto_acceptance_due_date is not None:
            self.auto_acceptance_due_date = auto_acceptance_due_date
        if ha_response_status is not None:
            self.ha_response_status = ha_response_status
        if ha_response_status_string is not None:
            self.ha_response_status_string = ha_response_status_string
        if ha_response_status_change_date is not None:
            self.ha_response_status_change_date = ha_response_status_change_date
        if ha_response_details is not None:
            self.ha_response_details = ha_response_details
        if promoter_response_status is not None:
            self.promoter_response_status = promoter_response_status
        if promoter_response_status_string is not None:
            self.promoter_response_status_string = promoter_response_status_string
        if promoter_response_status_change_date is not None:
            self.promoter_response_status_change_date = promoter_response_status_change_date
        if promoter_response_details is not None:
            self.promoter_response_details = promoter_response_details
        if is_auto_accepted is not None:
            self.is_auto_accepted = is_auto_accepted
        if non_compliance_reference_number is not None:
            self.non_compliance_reference_number = non_compliance_reference_number

    @property
    def inspection_date(self):
        """Gets the inspection_date of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_date of this InspectionSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._inspection_date

    @inspection_date.setter
    def inspection_date(self, inspection_date):
        """Sets the inspection_date of this InspectionSummaryResponse.


        :param inspection_date: The inspection_date of this InspectionSummaryResponse.  # noqa: E501
        :type: datetime
        """
        if inspection_date is None:
            raise ValueError("Invalid value for `inspection_date`, must not be `None`")  # noqa: E501

        self._inspection_date = inspection_date

    @property
    def inspection_response_type(self):
        """Gets the inspection_response_type of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_response_type of this InspectionSummaryResponse.  # noqa: E501
        :rtype: InspectionResponseTypeResponse
        """
        return self._inspection_response_type

    @inspection_response_type.setter
    def inspection_response_type(self, inspection_response_type):
        """Sets the inspection_response_type of this InspectionSummaryResponse.


        :param inspection_response_type: The inspection_response_type of this InspectionSummaryResponse.  # noqa: E501
        :type: InspectionResponseTypeResponse
        """
        if inspection_response_type is None:
            raise ValueError("Invalid value for `inspection_response_type`, must not be `None`")  # noqa: E501

        self._inspection_response_type = inspection_response_type

    @property
    def inspection_response_type_string(self):
        """Gets the inspection_response_type_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_response_type_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_response_type_string

    @inspection_response_type_string.setter
    def inspection_response_type_string(self, inspection_response_type_string):
        """Sets the inspection_response_type_string of this InspectionSummaryResponse.


        :param inspection_response_type_string: The inspection_response_type_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """
        if inspection_response_type_string is None:
            raise ValueError("Invalid value for `inspection_response_type_string`, must not be `None`")  # noqa: E501

        self._inspection_response_type_string = inspection_response_type_string

    @property
    def inspection_reference_number(self):
        """Gets the inspection_reference_number of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_reference_number of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_reference_number

    @inspection_reference_number.setter
    def inspection_reference_number(self, inspection_reference_number):
        """Sets the inspection_reference_number of this InspectionSummaryResponse.


        :param inspection_reference_number: The inspection_reference_number of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._inspection_reference_number = inspection_reference_number

    @property
    def inspection_type(self):
        """Gets the inspection_type of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_type of this InspectionSummaryResponse.  # noqa: E501
        :rtype: InspectionTypeResponse
        """
        return self._inspection_type

    @inspection_type.setter
    def inspection_type(self, inspection_type):
        """Sets the inspection_type of this InspectionSummaryResponse.


        :param inspection_type: The inspection_type of this InspectionSummaryResponse.  # noqa: E501
        :type: InspectionTypeResponse
        """
        if inspection_type is None:
            raise ValueError("Invalid value for `inspection_type`, must not be `None`")  # noqa: E501

        self._inspection_type = inspection_type

    @property
    def inspection_type_string(self):
        """Gets the inspection_type_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_type_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_type_string

    @inspection_type_string.setter
    def inspection_type_string(self, inspection_type_string):
        """Sets the inspection_type_string of this InspectionSummaryResponse.


        :param inspection_type_string: The inspection_type_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """
        if inspection_type_string is None:
            raise ValueError("Invalid value for `inspection_type_string`, must not be `None`")  # noqa: E501

        self._inspection_type_string = inspection_type_string

    @property
    def inspection_status(self):
        """Gets the inspection_status of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_status of this InspectionSummaryResponse.  # noqa: E501
        :rtype: InspectionStatusResponse
        """
        return self._inspection_status

    @inspection_status.setter
    def inspection_status(self, inspection_status):
        """Sets the inspection_status of this InspectionSummaryResponse.


        :param inspection_status: The inspection_status of this InspectionSummaryResponse.  # noqa: E501
        :type: InspectionStatusResponse
        """
        if inspection_status is None:
            raise ValueError("Invalid value for `inspection_status`, must not be `None`")  # noqa: E501

        self._inspection_status = inspection_status

    @property
    def inspection_status_string(self):
        """Gets the inspection_status_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_status_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_status_string

    @inspection_status_string.setter
    def inspection_status_string(self, inspection_status_string):
        """Sets the inspection_status_string of this InspectionSummaryResponse.


        :param inspection_status_string: The inspection_status_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """
        if inspection_status_string is None:
            raise ValueError("Invalid value for `inspection_status_string`, must not be `None`")  # noqa: E501

        self._inspection_status_string = inspection_status_string

    @property
    def inspection_category(self):
        """Gets the inspection_category of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_category of this InspectionSummaryResponse.  # noqa: E501
        :rtype: AllOfInspectionSummaryResponseInspectionCategory
        """
        return self._inspection_category

    @inspection_category.setter
    def inspection_category(self, inspection_category):
        """Sets the inspection_category of this InspectionSummaryResponse.


        :param inspection_category: The inspection_category of this InspectionSummaryResponse.  # noqa: E501
        :type: AllOfInspectionSummaryResponseInspectionCategory
        """

        self._inspection_category = inspection_category

    @property
    def inspection_category_string(self):
        """Gets the inspection_category_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_category_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_category_string

    @inspection_category_string.setter
    def inspection_category_string(self, inspection_category_string):
        """Sets the inspection_category_string of this InspectionSummaryResponse.


        :param inspection_category_string: The inspection_category_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._inspection_category_string = inspection_category_string

    @property
    def inspection_outcome(self):
        """Gets the inspection_outcome of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_outcome of this InspectionSummaryResponse.  # noqa: E501
        :rtype: AllOfInspectionSummaryResponseInspectionOutcome
        """
        return self._inspection_outcome

    @inspection_outcome.setter
    def inspection_outcome(self, inspection_outcome):
        """Sets the inspection_outcome of this InspectionSummaryResponse.


        :param inspection_outcome: The inspection_outcome of this InspectionSummaryResponse.  # noqa: E501
        :type: AllOfInspectionSummaryResponseInspectionOutcome
        """

        self._inspection_outcome = inspection_outcome

    @property
    def inspection_outcome_string(self):
        """Gets the inspection_outcome_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The inspection_outcome_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._inspection_outcome_string

    @inspection_outcome_string.setter
    def inspection_outcome_string(self, inspection_outcome_string):
        """Sets the inspection_outcome_string of this InspectionSummaryResponse.


        :param inspection_outcome_string: The inspection_outcome_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._inspection_outcome_string = inspection_outcome_string

    @property
    def reinspection_date_time(self):
        """Gets the reinspection_date_time of this InspectionSummaryResponse.  # noqa: E501


        :return: The reinspection_date_time of this InspectionSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._reinspection_date_time

    @reinspection_date_time.setter
    def reinspection_date_time(self, reinspection_date_time):
        """Sets the reinspection_date_time of this InspectionSummaryResponse.


        :param reinspection_date_time: The reinspection_date_time of this InspectionSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._reinspection_date_time = reinspection_date_time

    @property
    def auto_acceptance_due_date(self):
        """Gets the auto_acceptance_due_date of this InspectionSummaryResponse.  # noqa: E501


        :return: The auto_acceptance_due_date of this InspectionSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._auto_acceptance_due_date

    @auto_acceptance_due_date.setter
    def auto_acceptance_due_date(self, auto_acceptance_due_date):
        """Sets the auto_acceptance_due_date of this InspectionSummaryResponse.


        :param auto_acceptance_due_date: The auto_acceptance_due_date of this InspectionSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._auto_acceptance_due_date = auto_acceptance_due_date

    @property
    def ha_response_status(self):
        """Gets the ha_response_status of this InspectionSummaryResponse.  # noqa: E501


        :return: The ha_response_status of this InspectionSummaryResponse.  # noqa: E501
        :rtype: InspectionOutcomeStatusTypeResponse
        """
        return self._ha_response_status

    @ha_response_status.setter
    def ha_response_status(self, ha_response_status):
        """Sets the ha_response_status of this InspectionSummaryResponse.


        :param ha_response_status: The ha_response_status of this InspectionSummaryResponse.  # noqa: E501
        :type: InspectionOutcomeStatusTypeResponse
        """

        self._ha_response_status = ha_response_status

    @property
    def ha_response_status_string(self):
        """Gets the ha_response_status_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The ha_response_status_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._ha_response_status_string

    @ha_response_status_string.setter
    def ha_response_status_string(self, ha_response_status_string):
        """Sets the ha_response_status_string of this InspectionSummaryResponse.


        :param ha_response_status_string: The ha_response_status_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._ha_response_status_string = ha_response_status_string

    @property
    def ha_response_status_change_date(self):
        """Gets the ha_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501


        :return: The ha_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._ha_response_status_change_date

    @ha_response_status_change_date.setter
    def ha_response_status_change_date(self, ha_response_status_change_date):
        """Sets the ha_response_status_change_date of this InspectionSummaryResponse.


        :param ha_response_status_change_date: The ha_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._ha_response_status_change_date = ha_response_status_change_date

    @property
    def ha_response_details(self):
        """Gets the ha_response_details of this InspectionSummaryResponse.  # noqa: E501


        :return: The ha_response_details of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._ha_response_details

    @ha_response_details.setter
    def ha_response_details(self, ha_response_details):
        """Sets the ha_response_details of this InspectionSummaryResponse.


        :param ha_response_details: The ha_response_details of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._ha_response_details = ha_response_details

    @property
    def promoter_response_status(self):
        """Gets the promoter_response_status of this InspectionSummaryResponse.  # noqa: E501


        :return: The promoter_response_status of this InspectionSummaryResponse.  # noqa: E501
        :rtype: InspectionOutcomeStatusTypeResponse
        """
        return self._promoter_response_status

    @promoter_response_status.setter
    def promoter_response_status(self, promoter_response_status):
        """Sets the promoter_response_status of this InspectionSummaryResponse.


        :param promoter_response_status: The promoter_response_status of this InspectionSummaryResponse.  # noqa: E501
        :type: InspectionOutcomeStatusTypeResponse
        """

        self._promoter_response_status = promoter_response_status

    @property
    def promoter_response_status_string(self):
        """Gets the promoter_response_status_string of this InspectionSummaryResponse.  # noqa: E501


        :return: The promoter_response_status_string of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_response_status_string

    @promoter_response_status_string.setter
    def promoter_response_status_string(self, promoter_response_status_string):
        """Sets the promoter_response_status_string of this InspectionSummaryResponse.


        :param promoter_response_status_string: The promoter_response_status_string of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._promoter_response_status_string = promoter_response_status_string

    @property
    def promoter_response_status_change_date(self):
        """Gets the promoter_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501


        :return: The promoter_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._promoter_response_status_change_date

    @promoter_response_status_change_date.setter
    def promoter_response_status_change_date(self, promoter_response_status_change_date):
        """Sets the promoter_response_status_change_date of this InspectionSummaryResponse.


        :param promoter_response_status_change_date: The promoter_response_status_change_date of this InspectionSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._promoter_response_status_change_date = promoter_response_status_change_date

    @property
    def promoter_response_details(self):
        """Gets the promoter_response_details of this InspectionSummaryResponse.  # noqa: E501


        :return: The promoter_response_details of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_response_details

    @promoter_response_details.setter
    def promoter_response_details(self, promoter_response_details):
        """Sets the promoter_response_details of this InspectionSummaryResponse.


        :param promoter_response_details: The promoter_response_details of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._promoter_response_details = promoter_response_details

    @property
    def is_auto_accepted(self):
        """Gets the is_auto_accepted of this InspectionSummaryResponse.  # noqa: E501


        :return: The is_auto_accepted of this InspectionSummaryResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_auto_accepted

    @is_auto_accepted.setter
    def is_auto_accepted(self, is_auto_accepted):
        """Sets the is_auto_accepted of this InspectionSummaryResponse.


        :param is_auto_accepted: The is_auto_accepted of this InspectionSummaryResponse.  # noqa: E501
        :type: bool
        """

        self._is_auto_accepted = is_auto_accepted

    @property
    def non_compliance_reference_number(self):
        """Gets the non_compliance_reference_number of this InspectionSummaryResponse.  # noqa: E501


        :return: The non_compliance_reference_number of this InspectionSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._non_compliance_reference_number

    @non_compliance_reference_number.setter
    def non_compliance_reference_number(self, non_compliance_reference_number):
        """Sets the non_compliance_reference_number of this InspectionSummaryResponse.


        :param non_compliance_reference_number: The non_compliance_reference_number of this InspectionSummaryResponse.  # noqa: E501
        :type: str
        """

        self._non_compliance_reference_number = non_compliance_reference_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InspectionSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InspectionSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Street Manager Street Lookup API

    See API specification Resource Guide > Street Lookup API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.default_api import DefaultApi
# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.additional_special_designation_code_response import AdditionalSpecialDesignationCodeResponse
from swagger_client.models.additional_special_designations_periodicity_code_response import AdditionalSpecialDesignationsPeriodicityCodeResponse
from swagger_client.models.additional_special_designations_response import AdditionalSpecialDesignationsResponse
from swagger_client.models.all_of_additional_special_designations_response_asd_coordinate_geometry import AllOfAdditionalSpecialDesignationsResponseAsdCoordinateGeometry
from swagger_client.models.all_of_additional_special_designations_response_special_desig_periodicity_code import AllOfAdditionalSpecialDesignationsResponseSpecialDesigPeriodicityCode
from swagger_client.models.all_of_street_response_street_centre_point import AllOfStreetResponseStreetCentrePoint
from swagger_client.models.all_of_street_response_street_line import AllOfStreetResponseStreetLine
from swagger_client.models.coordinates import Coordinates
from swagger_client.models.geo_json_centre_point import GeoJSONCentrePoint
from swagger_client.models.geo_json_centre_point_type import GeoJSONCentrePointType
from swagger_client.models.geo_json_feature_type_response import GeoJSONFeatureTypeResponse
from swagger_client.models.geo_json_geometry import GeoJSONGeometry
from swagger_client.models.geo_json_multi_line_string import GeoJSONMultiLineString
from swagger_client.models.geo_json_multi_line_string_type import GeoJSONMultiLineStringType
from swagger_client.models.interest_authority import InterestAuthority
from swagger_client.models.primary_notice_authority import PrimaryNoticeAuthority
from swagger_client.models.reinstatement_type_code_response import ReinstatementTypeCodeResponse
from swagger_client.models.reinstatement_type_details import ReinstatementTypeDetails
from swagger_client.models.street_response import StreetResponse
from swagger_client.models.street_summary_response import StreetSummaryResponse
from swagger_client.models.streets_request import StreetsRequest
from swagger_client.models.usrn_street_request import UsrnStreetRequest



# coding: utf-8

# flake8: noqa

"""
    Street Manager GeoJSON API

    See API specification Resource Guide > GeoJSON API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.default_api import DefaultApi
# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.activity_activity_type_response import ActivityActivityTypeResponse
from swagger_client.models.activity_feature import ActivityFeature
from swagger_client.models.activity_properties import ActivityProperties
from swagger_client.models.activity_response import ActivityResponse
from swagger_client.models.all_of_work_properties_industry_sector import AllOfWorkPropertiesIndustrySector
from swagger_client.models.ancillary_info_feature import AncillaryInfoFeature
from swagger_client.models.ancillary_info_properties import AncillaryInfoProperties
from swagger_client.models.ancillary_info_response import AncillaryInfoResponse
from swagger_client.models.ancillary_info_status_response import AncillaryInfoStatusResponse
from swagger_client.models.ancillary_info_type_response import AncillaryInfoTypeResponse
from swagger_client.models.feature_collection_type import FeatureCollectionType
from swagger_client.models.feature_type import FeatureType
from swagger_client.models.forward_plan_feature import ForwardPlanFeature
from swagger_client.models.forward_plan_properties import ForwardPlanProperties
from swagger_client.models.forward_plan_response import ForwardPlanResponse
from swagger_client.models.forward_plan_status_response import ForwardPlanStatusResponse
from swagger_client.models.geo_json_centre_point import GeoJSONCentrePoint
from swagger_client.models.geo_json_centre_point_type import GeoJSONCentrePointType
from swagger_client.models.geo_json_feature_type_response import GeoJSONFeatureTypeResponse
from swagger_client.models.geo_json_geometry import GeoJSONGeometry
from swagger_client.models.hs2_act_limit_phase import Hs2ActLimitPhase
from swagger_client.models.hs2_act_limits_feature import Hs2ActLimitsFeature
from swagger_client.models.hs2_act_limits_response import Hs2ActLimitsResponse
from swagger_client.models.industry_sector_response import IndustrySectorResponse
from swagger_client.models.location_type_response import LocationTypeResponse
from swagger_client.models.material_classification_classification import MaterialClassificationClassification
from swagger_client.models.material_classification_classification_response import MaterialClassificationClassificationResponse
from swagger_client.models.material_classification_feature import MaterialClassificationFeature
from swagger_client.models.material_classification_material_type_response import MaterialClassificationMaterialTypeResponse
from swagger_client.models.material_classification_properties import MaterialClassificationProperties
from swagger_client.models.material_classification_response import MaterialClassificationResponse
from swagger_client.models.permit_status_response import PermitStatusResponse
from swagger_client.models.section58_duration_response import Section58DurationResponse
from swagger_client.models.section58_extent_response import Section58ExtentResponse
from swagger_client.models.section58_feature import Section58Feature
from swagger_client.models.section58_properties import Section58Properties
from swagger_client.models.section58_response import Section58Response
from swagger_client.models.section58_status_response import Section58StatusResponse
from swagger_client.models.traffic_management_type_response import TrafficManagementTypeResponse
from swagger_client.models.work_category_response import WorkCategoryResponse
from swagger_client.models.work_feature import WorkFeature
from swagger_client.models.work_properties import WorkProperties
from swagger_client.models.work_response import WorkResponse
